Class: RubyAem::Path

Inherits:
Object
  • Object
show all
Defined in:
lib/ruby_aem/path.rb

Overview

Path class contains API calls related to managing an AEM path.

Instance Method Summary collapse

Constructor Details

#initialize(client, name) ⇒ Object

Initialise a path.

Parameters:

  • client

    RubyAem::Client

  • name

    the name of the path, e.g. /etc/designs



26
27
28
29
30
31
# File 'lib/ruby_aem/path.rb', line 26

def initialize(client, name)
  @client = client
  @info = {
    name: name
  }
end

Instance Method Details

#activate(ignore_deactivated, only_modified) ⇒ Object

Activate a path.

Parameters:

  • ignore_deactivated

    if true, then deactivated items in the path will not be activated

  • only_modified

    if true, then only modified items in the path will be activated

Returns:

  • RubyAem::Result



38
39
40
41
42
43
# File 'lib/ruby_aem/path.rb', line 38

def activate(ignore_deactivated, only_modified)
  @info[:ignoredeactivated] = ignore_deactivated
  @info[:onlymodified] = only_modified

  @client.call(self.class, __callee__.to_s, @info)
end